@@ -6,7 +6,9 @@ testthat::test_that('obtainArea can correctly obtain the boundary layer of a cou
   country <- c('Norway', 'Sweden')
   proj <- '+proj=utm +zone=32 +ellps=WGS84 +datum=WGS84 +units=m +no_defs'
 
-  map <- obtainArea(country, proj)
+  map <- try(obtainArea(country, proj))
+
+  skip_if(inherits(map, 'try-error'))
 
   expect_equal(class(map), c('sf', 'data.frame'))
   expect_identical(st_crs(map)[2], st_crs(proj)[2])
@@ -19,5 +21,4 @@ testthat::test_that('obtainArea can correctly obtain the boundary layer of a cou
   expect_identical(st_crs(map2)[2], st_crs(proj2)[2])
 
 
-
 })
